@@ -39,6 +39,7 @@ class QRonosClient(object):
             'delete_items': f"{prefix}/delete_items/",
             'get_attributes': f"{prefix}/attributes/",
             'get_stages': f"{prefix}/stages/",
+            'get_stage_history': f"{prefix}/stage_history/",
         }
 
     def _get(self, *args, **kwargs):
@@ -247,3 +248,55 @@ class QRonosClient(object):
                 raise QRonosError("Unable to get stage data") from err
         elif response.status_code == 400:
             raise QRonosError(f"Bad Request - {response.json()}")
+
+    def get_item_stage_history(
+            self,
+            tracker=None,
+            unique_keys=None,
+            unique_key=None,
+            stages=None,
+            stage=None,
+            tracker_stage=None,
+            tracker_stages=None,
+    ):
+
+        """
+        Get item stages history with a tracker ID or using a unique key(s) which can be restricted by stage(s)
+
+        Keyword arguments:
+            :param tracker: The ID of the Tracker
+            :param unique_keys: A list of unique item keys
+            :param unique_key: A unique item key
+            :param stages: A list of stage ids (Stage model)
+            :param stage: The ID of a stage (Stage model)
+            :param tracker_stage: The ID of a tracker stage (TrackerStage model)
+            :param tracker_stages: A list of tracker stage ids (TrackerStage model)
+        :return: Item stages history
+        """
+
+        post_data = {}
+
+        if tracker:
+            post_data["tracker"] = tracker
+        if unique_keys:
+            post_data["unique_keys"] = unique_keys
+        elif unique_key:
+            post_data["unique_key"] = unique_key
+
+        if stages:
+            post_data["stages"] = stages
+        elif stage:
+            post_data["stage"] = stage
+        elif tracker_stage:
+            post_data["tracker_stage"] = tracker_stage
+        elif tracker_stages:
+            post_data["tracker_stages"] = tracker_stages
+
+        response = self._post(self.urls['get_stage_history'], json=post_data)
+        if response.status_code == 200:
+            try:
+                return response.json()
+            except Exception as err:
+                raise QRonosError("Unable to get stage history data") from err
+        elif response.status_code == 400:
+            raise QRonosError(f"Bad Request - {response.json()}")
